<a id="mypy-boto3-health"></a>

# mypy-boto3-health

[![PyPI - types-aiobotocore-health](https://img.shields.io/pypi/v/types-aiobotocore-health.svg?color=blue)](https://pypi.org/project/types-aiobotocore-health)
[![PyPI - Python Version](https://img.shields.io/pypi/pyversions/types-aiobotocore-health.svg?color=blue)](https://pypi.org/project/types-aiobotocore-health)
[![Docs](https://img.shields.io/readthedocs/mypy-boto3-builder.svg?color=blue)](https://mypy-boto3-builder.readthedocs.io/)
[![PyPI - Downloads](https://img.shields.io/pypi/dm/types-aiobotocore-health?color=blue)](https://pypistats.org/packages/types-aiobotocore-health)

![boto3.typed](https://github.com/vemel/mypy_boto3_builder/raw/main/logo.png)

Type annotations for
[boto3.Health 1.20.47](https://boto3.amazonaws.com/v1/documentation/api/latest/reference/services/health.html#Health)
service compatible with [VSCode](https://code.visualstudio.com/),
[PyCharm](https://www.jetbrains.com/pycharm/),
[Emacs](https://www.gnu.org/software/emacs/),
[Sublime Text](https://www.sublimetext.com/),
[mypy](https://github.com/python/mypy),
[pyright](https://github.com/microsoft/pyright) and other tools.

Generated by
[mypy-boto3-builder 6.4.2](https://github.com/vemel/mypy_boto3_builder).

More information can be found on
[boto3-stubs](https://pypi.org/project/boto3-stubs/) page and in
[types-aiobotocore-health docs](https://vemel.github.io/types_aiobotocore_docs/types_aiobotocore_health/)

See how it helps to find and fix potential bugs:

![boto3-stubs demo](https://github.com/vemel/mypy_boto3_builder/raw/main/demo.gif)

- [mypy-boto3-health](#mypy-boto3-health)
  - [How to install](#how-to-install)
    - [VSCode extension](#vscode-extension)
    - [From PyPI with pip](#from-pypi-with-pip)
  - [Usage](#usage)
    - [VSCode](#vscode)
    - [PyCharm](#pycharm)
    - [Other IDEs](#other-ides)
    - [mypy](#mypy)
    - [pyright](#pyright)
  - [Explicit type annotations](#explicit-type-annotations)
    - [Client annotations](#client-annotations)
    - [Paginators annotations](#paginators-annotations)

<a id="how-to-install"></a>

## How to install

<a id="vscode-extension"></a>

### VSCode extension

Add
[AWS Boto3](https://marketplace.visualstudio.com/items?itemName=Boto3typed.boto3-ide)
extension to your VSCode and run `AWS boto3: Quick Start` command.

Click `Modify` and select `boto3 common` and `Health`.

<a id="from-pypi-with-pip"></a>

### From PyPI with pip

Install `types-aiobotocore` for `Health` service.

```bash
python -m pip install types-aiobotocore[health]
```

<a id="usage"></a>

## Usage

<a id="vscode"></a>

### VSCode

- Install
  [Python extension](https://marketplace.visualstudio.com/items?itemName=ms-python.python)
- Install
  [Pylance extension](https://marketplace.visualstudio.com/items?itemName=ms-python.vscode-pylance)
- Set `Pylance` as your Python Language Server
- Install `types-aiobotocore[health]` in your environment:
  `python -m pip install 'types-aiobotocore[health]'`

Both type checking and auto-complete should work for `Health` service. No
explicit type annotations required, write your `boto3` code as usual.

<a id="pycharm"></a>

### PyCharm

- Install `types-aiobotocore[health]` in your environment:
  `python -m pip install 'types-aiobotocore[health]'`

Both type checking and auto-complete should work for `Health` service. No
explicit type annotations required, write your `aiobotocore` code as usual.
Auto-complete can be slow on big projects or if you have a lot of installed
`types-aiobotocore` submodules.

<a id="other-ides"></a>

### Other IDEs

Not tested, but as long as your IDE supports `mypy` or `pyright`, everything
should work.

<a id="mypy"></a>

### mypy

- Install `mypy`: `python -m pip install mypy`
- Install `types-aiobotocore[health]` in your environment:
  `python -m pip install 'types-aiobotocore[health]'`
- Run `mypy` as usual

Type checking should work for `Health` service. No explicit type annotations
required, write your `aiobotocore` code as usual.

<a id="pyright"></a>

### pyright

- Install `pyright`: `yarn global add pyright`
- Install `types-aiobotocore[health]` in your environment:
  `python -m pip install 'types-aiobotocore[health]'`
- Optionally, you can install `boto3-stubs` to `typings` folder.

Type checking should work for `Health` service. No explicit type annotations
required, write your `aiobotocore` code as usual.

<a id="explicit-type-annotations"></a>

## Explicit type annotations

<a id="client-annotations"></a>

### Client annotations

`HealthClient` provides annotations for `session.create_client("health")`.

```python
from aiobotocore.session import get_session

from types_aiobotocore_health import HealthClient

session = get_session()
with async session.create_client("health") as client:
    client: HealthClient
    # now client usage is checked by mypy and IDE should provide code auto-complete
```

<a id="paginators-annotations"></a>

### Paginators annotations

`types_aiobotocore_health.paginator` module contains type annotations for all
paginators.

````python
from aiobotocore.session import get_session

from types_aiobotocore_health import HealthClient
from types_aiobotocore_health.paginator import (
    DescribeAffectedAccountsForOrganizationPaginator,
    DescribeAffectedEntitiesPaginator,
    DescribeAffectedEntitiesForOrganizationPaginator,
    DescribeEventAggregatesPaginator,
    DescribeEventTypesPaginator,
    DescribeEventsPaginator,
    DescribeEventsForOrganizationPaginator,
)

session = get_session()
with async session.create_client("health") as client:
    client: HealthClient

    # Explicit type annotations are optional here
    # Type should be correctly discovered by mypy and IDEs
    # VSCode requires explicit type annotations
        describe_affected_accounts_for_organization_paginator: DescribeAffectedAccountsForOrganizationPaginator = client.get_paginator("describe_affected_accounts_for_organization")
        describe_affected_entities_paginator: DescribeAffectedEntitiesPaginator = client.get_paginator("describe_affected_entities")
        describe_affected_entities_for_organization_paginator: DescribeAffectedEntitiesForOrganizationPaginator = client.get_paginator("describe_affected_entities_for_organization")
        describe_event_aggregates_paginator: DescribeEventAggregatesPaginator = client.get_paginator("describe_event_aggregates")
        describe_event_types_paginator: DescribeEventTypesPaginator = client.get_paginator("describe_event_types")
        describe_events_paginator: DescribeEventsPaginator = client.get_paginator("describe_events")
        describe_events_for_organization_paginator: DescribeEventsForOrganizationPaginator = client.get_paginator("describe_events_for_organization")
    ```







### Literals

`types_aiobotocore_health.literals` module contains literals extracted from shapes
that can be used in user code for type checking.

```python
from types_aiobotocore_health.literals import (
    DescribeAffectedAccountsForOrganizationPaginatorName,
    DescribeAffectedEntitiesForOrganizationPaginatorName,
    DescribeAffectedEntitiesPaginatorName,
    DescribeEventAggregatesPaginatorName,
    DescribeEventTypesPaginatorName,
    DescribeEventsForOrganizationPaginatorName,
    DescribeEventsPaginatorName,
    entityStatusCodeType,
    eventAggregateFieldType,
    eventScopeCodeType,
    eventStatusCodeType,
    eventTypeCategoryType,
    ServiceName,
    PaginatorName,
)

def check_value(value: DescribeAffectedAccountsForOrganizationPaginatorName) -> bool:
    ...
````

### Typed dictionaries

`types_aiobotocore_health.type_defs` module contains structures and shapes
assembled to typed dictionaries for additional type checking.

```python
from types_aiobotocore_health.type_defs import (
    AffectedEntityTypeDef,
    DateTimeRangeTypeDef,
    DescribeAffectedAccountsForOrganizationRequestRequestTypeDef,
    DescribeAffectedAccountsForOrganizationResponseTypeDef,
    DescribeAffectedEntitiesForOrganizationRequestRequestTypeDef,
    DescribeAffectedEntitiesForOrganizationResponseTypeDef,
    DescribeAffectedEntitiesRequestRequestTypeDef,
    DescribeAffectedEntitiesResponseTypeDef,
    DescribeEntityAggregatesRequestRequestTypeDef,
    DescribeEntityAggregatesResponseTypeDef,
    DescribeEventAggregatesRequestRequestTypeDef,
    DescribeEventAggregatesResponseTypeDef,
    DescribeEventDetailsForOrganizationRequestRequestTypeDef,
    DescribeEventDetailsForOrganizationResponseTypeDef,
    DescribeEventDetailsRequestRequestTypeDef,
    DescribeEventDetailsResponseTypeDef,
    DescribeEventTypesRequestRequestTypeDef,
    DescribeEventTypesResponseTypeDef,
    DescribeEventsForOrganizationRequestRequestTypeDef,
    DescribeEventsForOrganizationResponseTypeDef,
    DescribeEventsRequestRequestTypeDef,
    DescribeEventsResponseTypeDef,
    DescribeHealthServiceStatusForOrganizationResponseTypeDef,
    EntityAggregateTypeDef,
    EntityFilterTypeDef,
    EventAccountFilterTypeDef,
    EventAggregateTypeDef,
    EventDescriptionTypeDef,
    EventDetailsErrorItemTypeDef,
    EventDetailsTypeDef,
    EventFilterTypeDef,
    EventTypeDef,
    EventTypeFilterTypeDef,
    EventTypeTypeDef,
    OrganizationAffectedEntitiesErrorItemTypeDef,
    OrganizationEventDetailsErrorItemTypeDef,
    OrganizationEventDetailsTypeDef,
    OrganizationEventFilterTypeDef,
    OrganizationEventTypeDef,
    PaginatorConfigTypeDef,
    ResponseMetadataTypeDef,
)

def get_structure() -> AffectedEntityTypeDef:
    return {
      ...
    }
```

## Versioning

`types-aiobotocore-health` version is the same as related `boto3` version and
follows [PEP 440](https://www.python.org/dev/peps/pep-0440/) format.

## Documentation

All type annotations can be found in
[types-aiobotocore-health docs](https://vemel.github.io/types_aiobotocore_docs/types_aiobotocore_health/)

## Support and contributing

This package is auto-generated. Please reports any bugs or request new features
in [mypy-boto3-builder](https://github.com/vemel/mypy_boto3_builder/issues/)
repository.
